<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression Error</source>
        <translation>İfade Hatası</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Dark Theme</source>
        <translation>Koyu Tema</translation>
    </message>
    <message>
        <source>Simple mode</source>
        <translation>Basit kip</translation>
    </message>
    <message>
        <source>Scientific mode</source>
        <translation>Bilimsel kip</translation>
    </message>
    <message>
        <source>Deepin Calculator</source>
        <translation>Deepin Hesap Makinesi</translation>
    </message>
    <message>
        <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
        <translation>Deepin Hesap Makinesi basit ve kullanımı kolay bir masaüstü hesap makinesidir. Toplama, çıkarma, çarpma ve bölme işlemleri yapılabilir.</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression Error</source>
        <translation>İfade Hatası</translation>
    </message>
</context>
</TS>